pilas.comportamientos.Saltar

Package pilas :: Module comportamientos :: Class Saltar |
[hide private]
[frames] | no frames]

# Class Saltar

source code

        object --+
                 |
    Comportamiento --+
                     |
                    Saltar

Realiza un salto, cambiando los atributos 'y'.

Instance Methods | [hide private]
__init__(self, velocidad_inicial=10, cuando_termina=None) x.__init__(...) initializes x; see help(type(x)) for signature | source code
iniciar(self, receptor) Se invoca cuando se anexa el comportamiento a un actor. | source code
actualizar(self) Actualiza el comportamiento en un instante dado. | source code
Inherited from `Comportamiento`: `terminar` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, velocidad_inicial=10, cuando_termina=None) (Constructor) | source code
x.__init__(...) initializes x; see help(type(x)) for signature Overrides: object.__init__ (inherited documentation)

### iniciar(self, receptor) | source code
Se invoca cuando se anexa el comportamiento a un actor. :param receptor: El actor que comenzará a ejecutar este comportamiento. Overrides: Comportamiento.iniciar

### actualizar(self) | source code
Actualiza el comportamiento en un instante dado. Si este metodo retorna True entonces el actor dejará de ejecutar este comportamiento. Overrides: Comportamiento.actualizar (inherited documentation)